summaryrefslogtreecommitdiffstats
path: root/src/gui/kdeext/KStartupLogo.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-09-06 20:59:29 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-09-06 20:59:29 +0000
commit11f31c37e5fa4889d9989f10272f44845449cb7b (patch)
tree4383da04a76c497950d957fc6120b0fd0d9082c2 /src/gui/kdeext/KStartupLogo.cpp
parent832eb69d571e8e518db45d0c0e6fbc0f00690209 (diff)
downloadrosegarden-11f31c37e5fa4889d9989f10272f44845449cb7b.tar.gz
rosegarden-11f31c37e5fa4889d9989f10272f44845449cb7b.zip
Initial TQt conversion
git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/rosegarden@1172292 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'src/gui/kdeext/KStartupLogo.cpp')
-rw-r--r--src/gui/kdeext/KStartupLogo.cpp46
1 files changed, 23 insertions, 23 deletions
diff --git a/src/gui/kdeext/KStartupLogo.cpp b/src/gui/kdeext/KStartupLogo.cpp
index 9a04d8f..821ebb1 100644
--- a/src/gui/kdeext/KStartupLogo.cpp
+++ b/src/gui/kdeext/KStartupLogo.cpp
@@ -25,8 +25,8 @@
#include <unistd.h>
#include <kapplication.h>
-#include <qpainter.h>
-#include <qfontmetrics.h>
+#include <tqpainter.h>
+#include <tqfontmetrics.h>
#include <kapp.h>
#include <kstddirs.h>
@@ -36,8 +36,8 @@
#include "KStartupLogo.h"
#include "misc/Debug.h"
-KStartupLogo::KStartupLogo(QWidget * parent, const char *name)
- : QWidget(parent, name,
+KStartupLogo::KStartupLogo(TQWidget * parent, const char *name)
+ : TQWidget(parent, name,
WStyle_Customize |
#if QT_VERSION >= 0x030100
WStyle_Splash
@@ -48,13 +48,13 @@ KStartupLogo::KStartupLogo(QWidget * parent, const char *name)
m_readyToHide(false),
m_showTip(true)
{
- QString pixmapFile = locate("appdata", "pixmaps/splash.png");
+ TQString pixmapFile = locate("appdata", "pixmaps/splash.png");
if (!pixmapFile)
return ;
m_pixmap.load(pixmapFile);
setBackgroundPixmap(m_pixmap);
- setGeometry(QApplication::desktop()->width() / 2 - m_pixmap.width() / 2,
- QApplication::desktop()->height() / 2 - m_pixmap.height() / 2,
+ setGeometry(TQApplication::desktop()->width() / 2 - m_pixmap.width() / 2,
+ TQApplication::desktop()->height() / 2 - m_pixmap.height() / 2,
m_pixmap.width(), m_pixmap.height());
}
@@ -64,16 +64,16 @@ KStartupLogo::~KStartupLogo()
m_instance = 0;
}
-void KStartupLogo::paintEvent(QPaintEvent*)
+void KStartupLogo::paintEvent(TQPaintEvent*)
{
// Print version number
- QPainter paint(this);
+ TQPainter paint(this);
- QFont defaultFont;
+ TQFont defaultFont;
defaultFont.setPixelSize(12);
paint.setFont(defaultFont);
- QFontMetrics metrics(defaultFont);
+ TQFontMetrics metrics(defaultFont);
int width = metrics.width(m_statusMessage) + 6;
if (width > 200)
width = 200;
@@ -81,11 +81,11 @@ void KStartupLogo::paintEvent(QPaintEvent*)
int y = m_pixmap.height() - 12;
// grep me: splash color
- // QColor bg(49, 94, 19); // color for 2006 splash
- QColor bg(19, 19, 19); // color for the 2008 splash
+ // TQColor bg(49, 94, 19); // color for 2006 splash
+ TQColor bg(19, 19, 19); // color for the 2008 splash
paint.setPen(bg);
paint.setBrush(bg);
- paint.drawRect(QRect(m_pixmap.width() - 220, m_pixmap.height() - 43,
+ paint.drawRect(TQRect(m_pixmap.width() - 220, m_pixmap.height() - 43,
220, (y + 8) - (m_pixmap.height() - 43)));
// paint.setPen(Qt::black);
@@ -93,10 +93,10 @@ void KStartupLogo::paintEvent(QPaintEvent*)
paint.setPen(Qt::white);
paint.setBrush(Qt::white);
- //QString version(VERSION);
+ //TQString version(VERSION);
//int sepIdx = version.find("-");
- QString versionLabel(VERSION);
- //QString("R%1 v%2").arg(version.left(sepIdx)).arg(version.mid(sepIdx + 1));
+ TQString versionLabel(VERSION);
+ //TQString("R%1 v%2").arg(version.left(sepIdx)).arg(version.mid(sepIdx + 1));
int versionWidth = metrics.width(versionLabel);
paint.drawText(m_pixmap.width() - versionWidth - 18,
@@ -106,11 +106,11 @@ void KStartupLogo::paintEvent(QPaintEvent*)
paint.drawText(m_pixmap.width() - (width + 10), y, m_statusMessage);
}
-void KStartupLogo::slotShowStatusMessage(QString message)
+void KStartupLogo::slotShowStatusMessage(TQString message)
{
m_statusMessage = message;
paintEvent(0);
- QApplication::flushX();
+ TQApplication::flushX();
}
void KStartupLogo::close()
@@ -123,15 +123,15 @@ void KStartupLogo::close()
}
}
- QWidget::close();
+ TQWidget::close();
}
-void KStartupLogo::mousePressEvent(QMouseEvent*)
+void KStartupLogo::mousePressEvent(TQMouseEvent*)
{
// for the haters of raising startlogos
if (m_readyToHide)
- hide(); // don't close, main() sets up a QTimer for that
+ hide(); // don't close, main() sets up a TQTimer for that
}
KStartupLogo* KStartupLogo::getInstance()
@@ -149,7 +149,7 @@ void KStartupLogo::hideIfStillThere()
{
if (m_instance)
m_instance->hide();
- // don't close, main() sets up a QTimer for that
+ // don't close, main() sets up a TQTimer for that
}